==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent.md <==
# AmazonEventBridgeSaasPartnerEvent


```text
aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent
```

```text
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')
```



| Illustration | AmazonEventBridgeSaasPartnerEvent | AmazonEventBridgeSaasPartnerEventCard | AmazonEventBridgeSaasPartnerEventGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent.png) | ![illustration for AmazonEventBridgeSaasPartnerEvent](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent.Local.png) | ![illustration for AmazonEventBridgeSaasPartnerEventCard](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEventCard.Local.png) | ![illustration for AmazonEventBridgeSaasPartnerEventGroup](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEventGroup.Local.png) |




## AmazonEventBridgeSaasPartnerEvent

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEvent
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEvent('AmazonEventBridgeSaasPartnerEvent', 'Amazon Event Bridge Saas Partner Event', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEvent
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEvent('AmazonEventBridgeSaasPartnerEvent', 'Amazon Event Bridge Saas Partner Event', 'an optional tech label')
@enduml
```

## AmazonEventBridgeSaasPartnerEventCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventCard('AmazonEventBridgeSaasPartnerEventCard', 'Amazon Event Bridge Saas Partner Event Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventCard('AmazonEventBridgeSaasPartnerEventCard', 'Amazon Event Bridge Saas Partner Event Card', 'an optional description')
@enduml
```

## AmazonEventBridgeSaasPartnerEventGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventGroup('AmazonEventBridgeSaasPartnerEventGroup', 'Amazon Event Bridge Saas Partner Event Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventGroup('AmazonEventBridgeSaasPartnerEventGroup', 'Amazon Event Bridge Saas Partner Event Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent.md <==
# AmazonEventBridgeSaasPartnerEvent


```text
aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent
```

```text
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')
```



| Illustration | AmazonEventBridgeSaasPartnerEvent | AmazonEventBridgeSaasPartnerEventCard | AmazonEventBridgeSaasPartnerEventGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent.png) | ![illustration for AmazonEventBridgeSaasPartnerEvent](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent.Local.png) | ![illustration for AmazonEventBridgeSaasPartnerEventCard](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEventCard.Local.png) | ![illustration for AmazonEventBridgeSaasPartnerEventGroup](../../../aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEventGroup.Local.png) |




## AmazonEventBridgeSaasPartnerEvent

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEvent
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEvent('AmazonEventBridgeSaasPartnerEvent', 'Amazon Event Bridge Saas Partner Event', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEvent
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEvent('AmazonEventBridgeSaasPartnerEvent', 'Amazon Event Bridge Saas Partner Event', 'an optional tech label')
@enduml
```

## AmazonEventBridgeSaasPartnerEventCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventCard('AmazonEventBridgeSaasPartnerEventCard', 'Amazon Event Bridge Saas Partner Event Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventCard
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventCard('AmazonEventBridgeSaasPartnerEventCard', 'Amazon Event Bridge Saas Partner Event Card', 'an optional description')
@enduml
```

## AmazonEventBridgeSaasPartnerEventGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventGroup('AmazonEventBridgeSaasPartnerEventGroup', 'Amazon Event Bridge Saas Partner Event Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonEventBridgeSaasPartnerEventGroup
include('aws-20210730/Resource/ApplicationIntegration/AmazonEventBridgeSaasPartnerEvent')

' renders the element
AmazonEventBridgeSaasPartnerEventGroup('AmazonEventBridgeSaasPartnerEventGroup', 'Amazon Event Bridge Saas Partner Event Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
